@@ -21,8 +21,8 @@ pub mod sdf;
 #[cfg(feature = "vtkio")]
 pub mod vtkio;
 
-#[cfg(feature = "proptest")]
-pub mod proptest_strategies;
+#[cfg(feature = "proptest-support")]
+pub mod proptest;
 
 pub trait BoundedGeometry<T>
 where
@@ -193,13 +193,32 @@ where
     }
 
     pub fn intersects(&self, other: &Self) -> bool {
-        for i in 0 .. D::dim() {
+        for i in 0..D::dim() {
             if !intervals_intersect([self.min[i], self.max[i]], [other.min[i], other.max[i]]) {
-                return false
+                return false;
             }
         }
         true
     }
+
+    /// Grows the bounding box by `distance` in all directions.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use fenris_geometry::AxisAlignedBoundingBox;
+    /// # use nalgebra::vector;
+    /// let aabb = AxisAlignedBoundingBox::new(vector![0.0, 0.0], vector![1.0, 1.0]);
+    /// let grown = aabb.grow_uniformly(1.0);
+    /// assert_eq!(grown.min(), &vector![-1.0, -1.0]);
+    /// assert_eq!(grown.max(), &vector![2.0, 2.0]);
+    /// ```
+    ///
+    pub fn grow_uniformly(&self, distance: T) -> Self {
+        let min = self.min().map(|b_i| b_i - distance);
+        let max = self.max().map(|b_i| b_i + distance);
+        Self::new(min, max)
+    }
 }
 
 fn intervals_intersect<T: RealField>([l1, u1]: [T; 2], [l2, u2]: [T; 2]) -> bool {
